About/Development - Carnegie Endowment for International Peace
Description: The Carnegie Endowment for International Peace is the oldest international affairs think tank in the United States and the first global think tank.

# Carnegie Endowment for International Peace

- Follow Carnegie
- Search
- Global Resources

- Research
- Experts
- Programs
- Events
- Topics

## Support Carnegie

Improving real-world outcomes is Carnegie’s business.

The Carnegie Endowment for International Peace is one of the world’s most highly regarded international affairs think tanks and the oldest of its kind in the United States. Three qualities have defined it over its history: excellence in scholarship, responsiveness to changing global circumstances, and a commitment to making a concrete difference in the world.

Ideas and analysis are valuable, but improving policies, decisionmaking, and real-world outcomes is Carnegie’s business. Today Carnegie has research centers in Moscow, Beijing, Beirut, and Brussels in addition to its headquarters in Washington, DC. It will soon open a center in New Delhi. As it enters its second century, the Carnegie Endowment is committed to building the premier global think tank by continuing its international expansion while maintaining the quality and coherence of the organization.

Carnegie is uniquely fortunate to be able to rely on its endowment, the legacy of Andrew Carnegie’s original 1910 gift of $10 million, to provide core funding for its programs. That funding, which covers close to 50 percent of Carnegie’s annual budget, ensures that scholars can maintain their independence and have the freedom they need to produce the highest quality work.

But Carnegie also depends on the generous support of people who value its mission and appreciate the quality and deep impact of its work. Carnegie is seeking to raise annual and program funds as well as new endowment as part of a unified campaign to complete its transformation into the world’s only global think tank.

#### Sources of Revenue, 2013

####
Summary of Expenses, 2013

#### Development Department

Carnegie Endowment
for International Peace 1779 Massachusetts Ave., NW
Washington, DC 20036
CarnegieEndowment.org/support

#### Contact

- Mary Ellen Fraser
  Chief Development Officer mfraser@ceip.org 202.939.2330
- Lea Kenig
  Deputy Chief Development Officer lkenig@ceip.org 202.939.2311
- Nikki Drevich
  Associate Director, Development ndrevich@ceip.org 202.939.2287
- Hilary McGraw
  Grants Manager hmcgraw@ceip.org 202.939.2231
- Katie Suatoni
  Development Associate ksuatoni@ceip.org 202.939.2396
- Rachel Wetz
  Stewardship Associate rwetz@ceip.org 202.939.2201

### Click here to view the Carnegie Brochure

### Click here to launch: 100 Years of Impact - A Timeline of the Carnegie Endowment for International Peace

2014 Global Go To
Think Tank Rankings
2013 Global Go To
Think Tank Rankings
2012 Global Go To
Think Tank Rankings
2011 Global Go To
Think Tank Rankings

- Financial Report June 30, 2015
- Carnegie’s Form 990 on GuideStar.org

#### Praise for Carnegie

“The Endowment’s rich history over the last century has brought together political leaders, policymakers, and public intellectuals from all countries …”

– Kevin Rudd
Former Australian Prime Minister

“[Carnegie is]…one of the centers of gravity of thinking about national security matters in our country.”

– General Martin Dempsey
Chairman of the Joint Chiefs of Staff

“Carnegie remains a first-rate source of policy analysis and practical guidance on all the major international issues and I rely on the advice and counsel of many Carnegie scholars.”

– John McCain
U.S. Senator

“The Carnegie Endowment has been a training ground for many of the allstars in the State Department during the Clinton administration and throughout this century. ….”

– Madeleine Albright
Former Secretary of State

“I appreciate the work Carnegie Endowment does...Above all, [it is] an approach that says, ‘We want to make a difference. We want to see if we can have an impact.’”

– Kofi Annan
Former Secretary General
of the United Nations

“I cannot think of a better alignment of communication, information, and getting people together.”

– Eric Schmidt
Executive Chairman of Google

“[T]his great vision of becoming a global think tank [is] badly needed in an interconnected world.”

– Nicholas Burns
Undersecretary of State
for Political Affairs

“The Carnegie Endowment for International Peace...has established itself as one of the most globally trusted talking-shops.”

– The Economist

“It is truly a global think tank…completely and appropriately reflective of the nature of the challenges that we face today.”

– John Kerry
U.S. Senator

“A force for global peace and security for 100 years.”

– John Brennan
Homeland Security Advisor

“An excellent institution that does important work to help establish stronger international laws and organizations.”

– His Royal Highness
Prince Turki Al-Faisal

“The Carnegie Endowment…has for a century been dedicated to understanding and preventing war and its myriad causes.”

– Robert Gates
U.S. Secretary of Defense

“The Carnegie Endowment is known on both sides of the aisle with great deal of respect for your active international engagement….”

– Michael Turner
U.S. Congressman

“[This event is]… a testament to the success that you’ve had in transforming Carnegie… into a truly global think tank.”

– Leon Panetta
U.S. Secretary of Defense

- Connect with Us
- Privacy Statement
- Help Desk
- Support The Global Think Tank

Carnegie Endowment for International Peace
1779 Massachusetts Avenue NW Washington, DC 20036-2103 Phone: 202 483 7600 Fax: 202 483 1840 Contact By Email
© 2016 All Rights Reserved
Please note...

You are leaving the website for the Carnegie-Tsinghua Center for Global Policy and entering a website for another of Carnegie's global centers.

请注意...

你将离开清华—卡内基中心网站，进入卡内基其他全球中心的网站。